@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from dateutil.parser import isoparse
 
 from hcloud.core.domain import BaseDomain, DomainIdentityMixin
@@ -107,10 +106,7 @@ class CreateManagedCertificateResponse(BaseDomain):
            Shows the progress of the certificate creation
     """
 
-    __slots__ = (
-        "certificate",
-        "action",
-    )
+    __slots__ = ("certificate", "action")
 
     def __init__(
         self,
