@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from hcloud.actions.client import BoundAction
 from hcloud.core.client import BoundModelBase, ClientEntityBase, GetEntityByNameMixin
 from hcloud.core.domain import add_meta_to_result
@@ -11,12 +10,17 @@ class BoundImage(BoundModelBase):
 
     def __init__(self, client, data):
         from hcloud.servers.client import BoundServer
+
         created_from = data.get("created_from")
         if created_from is not None:
-            data['created_from'] = BoundServer(client._client.servers, created_from, complete=False)
+            data["created_from"] = BoundServer(
+                client._client.servers, created_from, complete=False
+            )
         bound_to = data.get("bound_to")
         if bound_to is not None:
-            data['bound_to'] = BoundServer(client._client.servers, {"id": bound_to}, complete=False)
+            data["bound_to"] = BoundServer(
+                client._client.servers, {"id": bound_to}, complete=False
+            )
 
         super(BoundImage, self).__init__(client, data)
 
@@ -34,7 +38,9 @@ class BoundImage(BoundModelBase):
                Specifies how many results are returned by page
         :return: (List[:class:`BoundAction <hcloud.actions.client.BoundAction>`], :class:`Meta <hcloud.core.domain.Meta>`)
         """
-        return self._client.get_actions_list(self, sort=sort, page=page, per_page=per_page, status=status)
+        return self._client.get_actions_list(
+            self, sort=sort, page=page, per_page=per_page, status=status
+        )
 
     def get_actions(self, sort=None, status=None):
         # type: (Optional[List[str]], Optional[List[str]]) -> List[BoundAction]
@@ -83,15 +89,16 @@ class BoundImage(BoundModelBase):
 
 
 class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
-    results_list_attribute_name = 'images'
+    results_list_attribute_name = "images"
 
-    def get_actions_list(self,
-                         image,         # type: Image
-                         sort=None,     # type: Optional[List[str]]
-                         page=None,     # type: Optional[int]
-                         per_page=None,  # type: Optional[int]
-                         status=None,  # type: Optional[List[str]]
-                         ):
+    def get_actions_list(
+        self,
+        image,  # type: Image
+        sort=None,  # type: Optional[List[str]]
+        page=None,  # type: Optional[int]
+        per_page=None,  # type: Optional[int]
+        status=None,  # type: Optional[List[str]]
+    ):
         # type: (...) -> PageResults[List[BoundAction], Meta]
         """Returns a list of action objects for an image.
 
@@ -115,15 +122,23 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
             params["page"] = page
         if per_page is not None:
             params["per_page"] = per_page
-        response = self._client.request(url="/images/{image_id}/actions".format(image_id=image.id), method="GET", params=params)
-        actions = [BoundAction(self._client.actions, action_data) for action_data in response['actions']]
-        return add_meta_to_result(actions, response, 'actions')
+        response = self._client.request(
+            url="/images/{image_id}/actions".format(image_id=image.id),
+            method="GET",
+            params=params,
+        )
+        actions = [
+            BoundAction(self._client.actions, action_data)
+            for action_data in response["actions"]
+        ]
+        return add_meta_to_result(actions, response, "actions")
 
-    def get_actions(self,
-                    image,         # type: Image
-                    sort=None,  # type: Optional[List[str]]
-                    status=None,   # type: Optional[List[str]]
-                    ):
+    def get_actions(
+        self,
+        image,  # type: Image
+        sort=None,  # type: Optional[List[str]]
+        status=None,  # type: Optional[List[str]]
+    ):
         # type: (...) -> List[BoundAction]
         """Returns all action objects for an image.
 
@@ -143,20 +158,23 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
         :param id: int
         :return: :class:`BoundImage <hcloud.images.client.BoundImage
         """
-        response = self._client.request(url="/images/{image_id}".format(image_id=id), method="GET")
-        return BoundImage(self, response['image'])
+        response = self._client.request(
+            url="/images/{image_id}".format(image_id=id), method="GET"
+        )
+        return BoundImage(self, response["image"])
 
-    def get_list(self,
-                 name=None,            # type: Optional[str]
-                 label_selector=None,  # type: Optional[str]
-                 bound_to=None,        # type: Optional[List[str]]
-                 type=None,            # type: Optional[List[str]]
-                 sort=None,            # type: Optional[List[str]]
-                 page=None,            # type: Optional[int]
-                 per_page=None,        # type: Optional[int]
-                 status=None,           # type: Optional[List[str]]
-                 include_deprecated=None    # type: Optional[bool]
-                 ):
+    def get_list(
+        self,
+        name=None,  # type: Optional[str]
+        label_selector=None,  # type: Optional[str]
+        bound_to=None,  # type: Optional[List[str]]
+        type=None,  # type: Optional[List[str]]
+        sort=None,  # type: Optional[List[str]]
+        page=None,  # type: Optional[int]
+        per_page=None,  # type: Optional[int]
+        status=None,  # type: Optional[List[str]]
+        include_deprecated=None,  # type: Optional[bool]
+    ):
         # type: (...) -> PageResults[List[BoundImage]]
         """Get all images
 
@@ -182,37 +200,38 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
         """
         params = {}
         if name is not None:
-            params['name'] = name
+            params["name"] = name
         if label_selector is not None:
-            params['label_selector'] = label_selector
+            params["label_selector"] = label_selector
         if bound_to is not None:
-            params['bound_to'] = bound_to
+            params["bound_to"] = bound_to
         if type is not None:
-            params['type'] = type
+            params["type"] = type
         if sort is not None:
-            params['sort'] = sort
+            params["sort"] = sort
         if page is not None:
-            params['page'] = page
+            params["page"] = page
         if per_page is not None:
-            params['per_page'] = per_page
+            params["per_page"] = per_page
         if status is not None:
-            params['status'] = per_page
+            params["status"] = per_page
         if include_deprecated is not None:
-            params['include_deprecated'] = include_deprecated
+            params["include_deprecated"] = include_deprecated
         response = self._client.request(url="/images", method="GET", params=params)
-        images = [BoundImage(self, image_data) for image_data in response['images']]
+        images = [BoundImage(self, image_data) for image_data in response["images"]]
 
         return self._add_meta_to_result(images, response)
 
-    def get_all(self,
-                name=None,            # type: Optional[str]
-                label_selector=None,  # type: Optional[str]
-                bound_to=None,        # type: Optional[List[str]]
-                type=None,            # type: Optional[List[str]]
-                sort=None,            # type: Optional[List[str]]
-                status=None,          # type: Optional[List[str]]
-                include_deprecated=None  # type: Optional[bool]
-                ):
+    def get_all(
+        self,
+        name=None,  # type: Optional[str]
+        label_selector=None,  # type: Optional[str]
+        bound_to=None,  # type: Optional[List[str]]
+        type=None,  # type: Optional[List[str]]
+        sort=None,  # type: Optional[List[str]]
+        status=None,  # type: Optional[List[str]]
+        include_deprecated=None,  # type: Optional[bool]
+    ):
         # type: (...) -> List[BoundImage]
         """Get all images
 
@@ -232,7 +251,15 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
                Include deprecated images in the response. Default: False
         :return: List[:class:`BoundImage <hcloud.images.client.BoundImage>`]
         """
-        return super(ImagesClient, self).get_all(name=name, label_selector=label_selector, bound_to=bound_to, type=type, sort=sort, status=status, include_deprecated=include_deprecated)
+        return super(ImagesClient, self).get_all(
+            name=name,
+            label_selector=label_selector,
+            bound_to=bound_to,
+            type=type,
+            sort=sort,
+            status=status,
+            include_deprecated=include_deprecated,
+        )
 
     def get_by_name(self, name):
         # type: (str) -> BoundImage
@@ -265,8 +292,10 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
             data.update({"type": type})
         if labels is not None:
             data.update({"labels": labels})
-        response = self._client.request(url="/images/{image_id}".format(image_id=image.id), method="PUT", json=data)
-        return BoundImage(self, response['image'])
+        response = self._client.request(
+            url="/images/{image_id}".format(image_id=image.id), method="PUT", json=data
+        )
+        return BoundImage(self, response["image"])
 
     def delete(self, image):
         # type: (Image) -> bool
@@ -275,7 +304,9 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
         :param :class:`BoundImage <hcloud.images.client.BoundImage>` or :class:`Image <hcloud.images.domain.Image>`
         :return: bool
         """
-        self._client.request(url="/images/{image_id}".format(image_id=image.id), method="DELETE")
+        self._client.request(
+            url="/images/{image_id}".format(image_id=image.id), method="DELETE"
+        )
         # Return allays true, because the API does not return an action for it. When an error occurs a APIException will be raised
         return True
 
@@ -292,5 +323,11 @@ class ImagesClient(ClientEntityBase, GetEntityByNameMixin):
         if delete is not None:
             data.update({"delete": delete})
 
-        response = self._client.request(url="/images/{image_id}/actions/change_protection".format(image_id=image.id), method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/images/{image_id}/actions/change_protection".format(
+                image_id=image.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
